Generate (log) probability simplex over the joint type 1/type 2 responses
Source:R/metad_family.R
metad_pmf.RdGenerate (log) probability simplex over the joint type 1/type 2 responses
Usage
metad_pmf(
stimulus,
dprime,
c,
meta_dprime,
meta_c,
meta_c2_0,
meta_c2_1,
lcdf = normal_lcdf,
lccdf = normal_lccdf,
log = FALSE
)Arguments
- stimulus
the stimulus (0 or 1)
- dprime
the type 1 sensitivity
- c
the type 1 response criterion
- meta_dprime
the type 2 sensitivity
- meta_c
the type 1 criteriom for generating confidence ratings
- meta_c2_0
the type 2 response criteria for
"0"responses, indexed by increasing confidence levels- meta_c2_1
the type 2 response criteria for
"1"responses, indexed by increasing confidence levels- lcdf
The log cumulative distribution function for the underlying distribution in the metad' model. By default, uses the normal distribution with a standard deviation of
1.- lccdf
The log complement cumulative distribution function for the underlying distribution in the metad' model. By default, uses the normal distribution with a standard deviation of
1.- log
if TRUE, return log probabilities instead of probabilities